slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSGetDS

Obtain the direct solver object associated to the eigensolver object.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSGetDS(EPS eps,DS *ds)

Not Collective

### Input Parameters

| eps | - eigensolver context obtained from EPSCreate()

### Output Parameter

| ds | - direct solver context

### See Also

EPSSetDS()

### Level

advanced

### Location

src/eps/interface/epsbasic.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages